// Arrow.java
// Definition of class Arrow (version 1)
import java.awt.Graphics; 

/**
*  <b>Arrow</b> describes a two-dimensional Arrow.
*
*/


public class Arrow extends Line {

	public static final int AH_OUTLINE = 1;
	public static final int AH_OPEN = 2;
	public static final int AH_FILLED = 3;
	private static final double std_size = 0.3;

	private double arrow_size = std_size;
	private int arrow_type = AH_FILLED;

	public Arrow(Point a, Point b) { super(a,b); }
	public Arrow(double x1, double y1, double x2, double y2)
	{
		super(x1,y1,x2,y2);
	}

	public void setArrow(double x1, double y1, double x2, double y2)
	{
		pa.setPoint(x1,y1);
		pb.setPoint(x2,y2);
	}

	public int getArrowHead() { return arrow_type; }
	public double getArrowSize() { return arrow_size/std_size; }
	public void setArrowHead(int type) {
		switch (type) {
			case AH_OUTLINE:
			case AH_OPEN:
				arrow_type = type;
			default:
				arrow_type = AH_FILLED;
		}
	}
	public void setArrowSize(double size)
	{
		arrow_size =(size>0.0? size * std_size: std_size);
	}

	public void draw(Graphics g)
	{
		final double fa = 5.0; // tan of arrow angle
		final double fb = 0.9; // break in base Arrow
		int x[] = new int[4];
		int y[] = new int[4];
		Point va, vf;
		va = getDirection();
		va.setSize(1.0);
		vf = new Point(va.x,va.y);
		vf.setSize(1.0/fa);

		Point pc = new Point(pb.x+arrow_size*(vf.y-va.x),pb.y-arrow_size*(vf.x+va.y));
		Point pd = new Point(pb.x-arrow_size*va.x*fb,pb.y-arrow_size*va.y*fb);
		Point pe = new Point(pb.x-arrow_size*(vf.y+va.x),pb.y+arrow_size*(vf.x-va.y));

		x[0] = pc.getX();
		y[0] = pc.getY();
		x[1] = pd.getX();
		y[1] = pd.getY();
		x[2] = pe.getX();
		y[2] = pe.getY();
		x[3] = pb.getX();
		y[3] = pb.getY();
		g.drawLine(pa.getX(),pa.getY(),x[3],y[3]);
		switch (arrow_type) {
			case AH_OUTLINE:
				g.drawPolygon(x,y,4);
				break;
			case AH_OPEN:
				g.drawLine(x[0],y[0],x[3],y[3]);
				g.drawLine(x[2],y[2],x[3],y[3]);
				break;
			default:
				g.fillPolygon(x,y,4);
				break;
		}
	}
}	